'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

var _toConsumableArray2 = require('babel-runtime/helpers/toConsumableArray');

var _toConsumableArray3 = _interopRequireDefault(_toConsumableArray2);

var _defineProperty = require('babel-runtime/core-js/object/define-property');

var _defineProperty2 = _interopRequireDefault(_defineProperty);

var _keys = require('babel-runtime/core-js/object/keys');

var _keys2 = _interopRequireDefault(_keys);

var _typeof2 = require('babel-runtime/helpers/typeof');

var _typeof3 = _interopRequireDefault(_typeof2);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _themeable = require('./themeable');

var _themeable2 = _interopRequireDefault(_themeable);

var _reactJsonTree = require('react-json-tree');

var _reactJsonTree2 = _interopRequireDefault(_reactJsonTree);

var _ActionPreviewHeader = require('./ActionPreviewHeader');

var _ActionPreviewHeader2 = _interopRequireDefault(_ActionPreviewHeader);

var _JSONDiff = require('./JSONDiff');

var _JSONDiff2 = _interopRequireDefault(_JSONDiff);

var _immutable = require('immutable');

var _isIterable = require('./isIterable');

var _isIterable2 = _interopRequireDefault(_isIterable);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var IS_IMMUTABLE_KEY = '@@__IS_IMMUTABLE__@@';

function isImmutable(value) {
  return _immutable.Iterable.isKeyed(value) || _immutable.Iterable.isIndexed(value) || _immutable.Iterable.isIterable(value);
}

function _getItemString(createTheme, type, data) {
  var text = undefined;

  function getShortTypeString(val) {
    if ((0, _isIterable2.default)(val) && !isImmutable(val)) {
      return '(…)';
    } else if (Array.isArray(val)) {
      return val.length > 0 ? '[…]' : '[]';
    } else if (val === null) {
      return 'null';
    } else if (val === undefined) {
      return 'undef';
    } else if ((typeof val === 'undefined' ? 'undefined' : (0, _typeof3.default)(val)) === 'object') {
      return (0, _keys2.default)(val).length > 0 ? '{…}' : '{}';
    } else if (typeof val === 'function') {
      return 'fn';
    } else if (typeof val === 'string') {
      return '"' + (val.substr(0, 10) + (val.length > 10 ? '…' : '')) + '"';
    } else if ((typeof val === 'undefined' ? 'undefined' : (0, _typeof3.default)(val)) === 'symbol') {
      return 'symbol';
    } else {
      return val;
    }
  }

  if (type === 'Object') {
    var keys = (0, _keys2.default)(data);
    var str = keys.slice(0, 2).map(function (key) {
      return key + ': ' + getShortTypeString(data[key]);
    }).concat(keys.length > 2 ? ['…'] : []).join(', ');

    text = '{ ' + str + ' }';
  } else if (type === 'Array') {
    var str = data.slice(0, 2).map(getShortTypeString).concat(data.length > 2 ? ['…'] : []).join(', ');

    text = '[' + str + ']';
  } else {
    text = type;
  }

  var immutableStr = data[IS_IMMUTABLE_KEY] ? 'Immutable' : '';

  return _react2.default.createElement(
    'span',
    createTheme('treeItemHint'),
    ' ',
    immutableStr,
    ' ',
    text
  );
}

function convertImmutable(value) {
  if (isImmutable(value)) {
    value = value.toSeq().__toJS();
    (0, _defineProperty2.default)(value, IS_IMMUTABLE_KEY, {
      enumerable: false,
      configurable: false,
      writable: false,
      value: true
    });
  }

  return value;
}

var ActionPreview = function ActionPreview(_ref) {
  var theme = _ref.theme;
  var delta = _ref.delta;
  var nextState = _ref.nextState;
  var onInspectPath = _ref.onInspectPath;
  var inspectedPath = _ref.inspectedPath;
  var tab = _ref.tab;
  var onSelectTab = _ref.onSelectTab;
  var action = _ref.action;
  var base16Theme = _ref.base16Theme;

  var createTheme = (0, _themeable2.default)(theme);

  var labelRenderer = function labelRenderer(key) {
    for (var _len = arguments.length, rest = Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
      rest[_key - 1] = arguments[_key];
    }

    return _react2.default.createElement(
      'span',
      null,
      _react2.default.createElement(
        'span',
        createTheme('treeItemKey'),
        key
      ),
      _react2.default.createElement(
        'span',
        (0, _extends3.default)({}, createTheme('treeItemPin'), {
          onClick: function onClick() {
            return onInspectPath([].concat((0, _toConsumableArray3.default)(inspectedPath.slice(0, inspectedPath.length - 1)), (0, _toConsumableArray3.default)([key].concat(rest).reverse())));
          } }),
        '(pin)'
      )
    );
  };

  return _react2.default.createElement(
    'div',
    (0, _extends3.default)({ key: 'actionPreview' }, createTheme('actionPreview')),
    _react2.default.createElement(_ActionPreviewHeader2.default, {
      theme: theme, inspectedPath: inspectedPath, onInspectPath: onInspectPath, tab: tab, onSelectTab: onSelectTab
    }),
    tab === 'Diff' && delta && _react2.default.createElement(_JSONDiff2.default, { delta: delta, labelRenderer: labelRenderer, theme: theme, base16Theme: base16Theme }),
    tab === 'Diff' && !delta && _react2.default.createElement(
      'div',
      createTheme('stateDiffEmpty'),
      '(states are equal)'
    ),
    (tab === 'State' && nextState || tab === 'Action') && _react2.default.createElement(_reactJsonTree2.default, { labelRenderer: labelRenderer,
      theme: base16Theme,
      data: tab === 'Action' ? action : nextState,
      getItemString: function getItemString(type, data) {
        return _getItemString(createTheme, type, data);
      },
      postprocessValue: convertImmutable,
      getItemStringStyle: function getItemStringStyle(type, expanded) {
        return { display: expanded ? 'none' : 'inline' };
      },
      hideRoot: true })
  );
};

exports.default = ActionPreview;