'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

var _defineProperty2 = require('babel-runtime/helpers/defineProperty');

var _defineProperty3 = _interopRequireDefault(_defineProperty2);

var _styles;

exports.default = createDefaultTheme;

var _jss = require('jss');

var _jss2 = _interopRequireDefault(_jss);

var _jssVendorPrefixer = require('jss-vendor-prefixer');

var _jssVendorPrefixer2 = _interopRequireDefault(_jssVendorPrefixer);

var _jssNested = require('jss-nested');

var _jssNested2 = _interopRequireDefault(_jssNested);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

_jss2.default.use((0, _jssVendorPrefixer2.default)());
_jss2.default.use((0, _jssNested2.default)());

var defaultBase16Theme = {
  base00: '#FFF',
  base01: '#FAFAFA',
  base02: '#DDD',
  base03: '#777',
  base04: '#999',
  base05: '#EEE',
  base06: '#666',
  base07: '#AAE',
  base08: '#F99',
  base09: '#933',
  base0A: '#FFA',
  base0B: '#9F9',
  base0C: '#0a6ebd',
  base0D: '#933',
  base0E: '#939',
  base0F: '#993'
};

var colorMap = function colorMap(theme) {
  return {
    TEXT_COLOR: theme.base06,
    BACKGROUND_COLOR: theme.base00,
    SELECTED_BACKGROUND_COLOR: theme.base01,
    HEADER_BACKGROUND_COLOR: theme.base01,
    HEADER_BORDER_COLOR: theme.base02,
    BORDER_COLOR: theme.base02,
    LIST_BORDER_COLOR: theme.base02,
    ACTION_TIME_BACK_COLOR: theme.base02,
    ACTION_TIME_COLOR: theme.base03,
    PIN_COLOR: theme.base04,
    ITEM_HINT_COLOR: theme.base0F,
    TAB_BACK_COLOR: theme.base02,
    TAB_BORDER_COLOR: theme.base02,
    DIFF_ADD_COLOR: theme.base0B,
    DIFF_REMOVE_COLOR: theme.base08,
    DIFF_ARROW_COLOR: theme.base0E,
    LINK_COLOR: theme.base0C
  };
};

var colors = function colors(map) {
  return {
    inspectorColor: {
      'background-color': map.BACKGROUND_COLOR,
      color: map.TEXT_COLOR
    },

    actionListColor: {
      'background-color': map.BACKGROUND_COLOR,
      'border-color': map.LIST_BORDER_COLOR
    },

    actionListItemColor: {
      'border-bottom-color': map.BORDER_COLOR
    },

    actionListItemSelectedColor: {
      'background-color': map.SELECTED_BACKGROUND_COLOR
    },

    actionListItemTimeColor: {
      'background-color': map.ACTION_TIME_BACK_COLOR,
      color: map.ACTION_TIME_COLOR
    },

    actionPreviewColor: {
      'background-color': map.BACKGROUND_COLOR
    },

    stateDiffEmptyColor: {
      color: '#AAA'
    },

    inspectedPathColor: {
      'background-color': map.HEADER_BACKGROUND_COLOR,
      'border-color': map.BORDER_COLOR
    },

    treeItemPinColor: {
      color: map.PIN_COLOR
    },

    previewHeaderColor: {
      'background-color': map.HEADER_BACKGROUND_COLOR,
      'border-bottom': map.HEADER_BORDER_COLOR
    },

    treeItemHintColor: {
      color: map.ITEM_HINT_COLOR
    },

    tabSelectorButtonColor: {
      'border-color': map.TAB_BORDER_COLOR,
      '&:before': {
        opacity: 0.5,
        'background-color': map.TAB_BACK_COLOR
      },
      '&:hover:before': {
        opacity: 0
      }
    },

    tabSelectorButtonSelectedColor: {
      '&:before': {
        opacity: 0
      }
    },

    diffColor: {
      color: map.TEXT_COLOR
    },

    diffAddColor: {
      '&:before': {
        'background-color': map.DIFF_ADD_COLOR
      }
    },

    diffRemoveColor: {
      '&:before': {
        'background-color': map.DIFF_REMOVE_COLOR
      }
    },

    diffUpdateFromColor: {
      '&:before': {
        'background-color': map.DIFF_REMOVE_COLOR
      }
    },

    diffUpdateToColor: {
      '&:before': {
        'background-color': map.DIFF_ADD_COLOR
      }
    },

    diffUpdateArrowColor: {
      color: map.DIFF_ARROW_COLOR
    },

    inspectedPathKeyLinkColor: {
      color: map.LINK_COLOR,
      opacity: 0.8,
      '&:hover': {
        color: map.LINK_COLOR,
        opacity: 1
      }
    },

    actionListSearchColor: {
      'border-color': map.BORDER_COLOR,
      'background-color': map.BACKGROUND_COLOR,
      color: map.TEXT_COLOR
    }
  };
};

var styles = (_styles = {
  inspector: {
    display: 'flex',
    'flex-direction': 'column',
    width: '100%',
    height: '100%',
    'font-family': 'monaco, Consolas, "Lucida Console", monospace',
    'font-size': '12px',
    'font-smoothing': 'antialiased',
    'line-height': '1.5em'
  },

  actionListItem: {
    'border-bottom-width': '1px',
    'border-bottom-style': 'solid',
    display: 'flex',
    'align-items': 'flex-start',
    'justify-content': 'space-between',
    padding: '0.5rem 1rem',
    cursor: 'pointer',

    '&:last-child': {
      'border-bottom-width': 0
    }
  },

  actionListItemTime: {
    padding: '0.4rem 0.6rem',
    'border-radius': '3px',
    'font-size': '0.8em',
    'line-height': '1em',
    'flex-shrink': 0
  },

  actionListItemName: {
    overflow: 'auto',
    'text-overflow': 'ellipsis'
  },

  actionPreview: {
    '& pre': {
      border: 'inherit',
      'border-radius': '3px',
      'line-height': 'inherit',
      color: 'inherit'
    }
  },

  actionList: {
    'flex-basis': '40%',
    'flex-shrink': 0,
    'overflow-y': 'auto',
    'border-bottom-width': '3px',
    'border-bottom-style': 'double'
  }

}, (0, _defineProperty3.default)(_styles, 'actionPreview', {
  'flex-grow': 1,
  'overflow-y': 'auto'
}), (0, _defineProperty3.default)(_styles, 'inspectorWide', {
  'flex-direction': 'row'
}), (0, _defineProperty3.default)(_styles, 'actionListWide', {
  'flex-basis': '40%',
  'border-bottom': 'none',
  'border-right-width': '3px',
  'border-right-style': 'double'
}), (0, _defineProperty3.default)(_styles, 'stateDiff', {
  padding: '0.5rem 0'
}), (0, _defineProperty3.default)(_styles, 'stateDiffEmpty', {
  padding: '0.5rem 1rem'
}), (0, _defineProperty3.default)(_styles, 'inspectedPath', {
  padding: '0.6rem 0rem'
}), (0, _defineProperty3.default)(_styles, 'inspectedPathKey', {
  '&:not(:last-child):after': {
    content: '" > "'
  }
}), (0, _defineProperty3.default)(_styles, 'inspectedPathKeyLink', {
  cursor: 'pointer',
  '&:hover': {
    'text-decoration': 'underline'
  }
}), (0, _defineProperty3.default)(_styles, 'treeItemPin', {
  'font-size': '0.7em',
  'padding-left': '0.5rem',
  cursor: 'pointer',
  '&:hover': {
    'text-decoration': 'underline'
  }
}), (0, _defineProperty3.default)(_styles, 'treeItemKey', {
  cursor: 'pointer'
}), (0, _defineProperty3.default)(_styles, 'treeItemHint', {
  opacity: 0.9
}), (0, _defineProperty3.default)(_styles, 'previewHeader', {
  padding: '0.5rem 1rem',
  'align-items': 'center',
  'border-bottom-width': '1px',
  'border-bottom-style': 'solid'
}), (0, _defineProperty3.default)(_styles, 'actionListSearch', {
  outline: 'none',
  'border-top': 'none',
  'border-left': 'none',
  'border-right': 'none',
  'border-bottom-width': '1px',
  'border-bottom-style': 'solid',
  width: '100%',
  padding: '0.5rem 1rem'
}), (0, _defineProperty3.default)(_styles, 'tabSelector', {
  position: 'relative',
  'z-index': 1,
  display: 'inline-flex',
  float: 'right',
  'margin-bottom': '0.5rem'
}), (0, _defineProperty3.default)(_styles, 'tabSelectorButton', {
  cursor: 'pointer',
  position: 'relative',
  padding: '0.5rem 1rem',
  'border-style': 'solid',
  'border-width': '1px',
  'border-left-width': 0,

  '&:first-child': {
    'border-left-width': '1px',
    'border-top-left-radius': '3px',
    'border-bottom-left-radius': '3px'
  },

  '&:last-child': {
    'border-top-right-radius': '3px',
    'border-bottom-right-radius': '3px'
  },

  '&:before': {
    content: '""',
    position: 'absolute',
    'z-index': -1,
    left: 0,
    top: 0,
    width: '100%',
    height: '100%'
  }
}), (0, _defineProperty3.default)(_styles, 'diffWrap', {
  position: 'relative',
  'z-index': 1
}), (0, _defineProperty3.default)(_styles, 'diff', {
  padding: '0.2rem 0.3rem',
  'border-radius': '3px',
  position: 'relative',
  '&:before': {
    'border-radius': '3px',
    content: '""',
    position: 'absolute',
    'z-index': -1,
    left: 0,
    width: '100%',
    height: '100%',
    opacity: 0.5
  }
}), (0, _defineProperty3.default)(_styles, 'diffRemove', {
  'text-decoration': 'line-through'
}), (0, _defineProperty3.default)(_styles, 'diffUpdateFrom', {
  'text-decoration': 'line-through'
}), _styles);

function createDefaultTheme(base16Theme) {
  var sheet = _jss2.default.createStyleSheet((0, _extends3.default)({}, colors(colorMap(base16Theme || defaultBase16Theme)), styles)).attach();

  return sheet.classes;
}